%define realname        zstd
%define libmajor        1
%define libname         %mklibname %{realname} %{libmajor}
%define libname_devel   %mklibname %{realname} -d

# enable pzstd support by default
%bcond_without pzstd

# Something is broken with how Iurt sets up the environment
# for the test suite's run...
%bcond_without check

Name:           zstd
Version:        1.5.7
Release:        %mkrel 2
Summary:        Zstd compression library
Group:          Archiving/Compression
License:        BSD and GPLv2
URL:            http://www.zstd.net/
Source0:        https://github.com/facebook/zstd/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(liblzma)

%description
Zstd, short for Zstandard, is a fast lossless compression algorithm,
targeting real-time compression scenarios at zlib-level compression ratio.

%package -n %{libname}
Summary:        Zstd shared library
Group:          System/Libraries

%description -n %{libname}
Zstandard compression shared library.

%package -n %{libname_devel}
Summary:        Header files for Zstd library
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{libname_devel}
Header files for Zstd library.


%prep
%setup -q
find -name .gitignore -delete

%build
%global _vpath_srcdir build/cmake/
%define _vpath_builddir build-%{_target}

%cmake -GNinja \
  -DZSTD_PROGRAMS_LINK_SHARED:BOOL=ON \
  -DZSTD_BUILD_STATIC:BOOL=OFF \
  -DZSTD_BUILD_SHARED:BOOL=ON \
  -DZSTD_BUILD_CONTRIB:BOOL=%{?with_pzstd:ON}%{?!with_pzstd:OFF} \
  -DZSTD_BUILD_TESTS:BOOL=OFF
%cmake_build

# for tests
%if %{with check}
%define _vpath_builddir build-%{_target}-check
%cmake -GNinja \
  -DZSTD_PROGRAMS_LINK_SHARED:BOOL=ON \
  -DZSTD_BUILD_STATIC:BOOL=ON \
  -DZSTD_BUILD_SHARED:BOOL=ON \
  -DZSTD_BUILD_CONTRIB:BOOL=%{?with_pzstd:ON}%{?!with_pzstd:OFF} \
  -DZSTD_BUILD_TESTS:BOOL=ON
%cmake_build

%check
%define _vpath_builddir build-%{_target}-check
export LD_LIBRARY_PATH=$(pwd)/%{_vpath_builddir}/lib
%ctest
%endif

%install
%define _vpath_builddir build-%{_target}
%cmake_install

%if %{with pzstd}
ln -s %{name}.1 %{buildroot}%{_mandir}/man1/pzstd.1
%endif

%files
%license LICENSE
%doc CHANGELOG README.md
%{_bindir}/zstd
%if %{with pzstd}
%doc %{_vpath_builddir}/contrib/gen_html/zstd_manual.html
%{_bindir}/pzstd
%{_mandir}/man1/pzstd.1*
%endif
%{_bindir}/zstdmt
%{_bindir}/unzstd
%{_bindir}/zstdcat
%{_bindir}/zstdgrep
%{_bindir}/zstdless
%{_mandir}/man1/zstd.1*
%{_mandir}/man1/unzstd.1*
%{_mandir}/man1/zstdcat.1*
%{_mandir}/man1/zstdgrep.1*
%{_mandir}/man1/zstdless.1*

%files -n %{libname}
%license LICENSE
%{_libdir}/libzstd.so.%{libmajor}{,.*}

%files -n %{libname_devel}
%{_includedir}/zdict.h
%{_includedir}/zstd.h
%{_includedir}/zstd_errors.h
%{_libdir}/pkgconfig/libzstd.pc
%{_libdir}/cmake/zstd/
%{_libdir}/libzstd.so


%changelog
* Mon Jul 07 2025 umeabot <umeabot> 1.5.7-2.mga10
+ Revision: 2250131
- Mageia 10 Mass Rebuild

* Thu Mar 27 2025 daviddavid <daviddavid> 1.5.7-1.mga10
+ Revision: 2170376
- new version: 1.5.7

* Fri Apr 05 2024 wally <wally> 1.5.6-2.mga10
+ Revision: 2054702
- basesystem rebuild for i686

* Fri Mar 29 2024 daviddavid <daviddavid> 1.5.6-1.mga10
+ Revision: 2053124
- new version: 1.5.6

* Sat Apr 22 2023 luigiwalser <luigiwalser> 1.5.5-1.mga9
+ Revision: 1954007
- 1.5.5

* Tue Feb 14 2023 daviddavid <daviddavid> 1.5.4-2.mga9
+ Revision: 1941998
- re-enable testsuite

* Mon Feb 13 2023 daviddavid <daviddavid> 1.5.4-1.mga9
+ Revision: 1941550
- new version: 1.5.4

* Sat Dec 31 2022 wally <wally> 1.5.2-6.mga9
+ Revision: 1928358
- build static lib only for tests

* Fri Dec 30 2022 wally <wally> 1.5.2-5.mga9
+ Revision: 1928241
- build using cmake + ninja

* Fri Jul 22 2022 wally <wally> 1.5.2-4.mga9
+ Revision: 1870127
- fix prefix and libdir in pkgconf .pc file

* Fri May 20 2022 tv <tv> 1.5.2-3.mga9
+ Revision: 1859604
- ThreadPool segfault fixed so build pzst everywhere

* Wed Mar 23 2022 umeabot <umeabot> 1.5.2-2.mga9
+ Revision: 1821248
- Mageia 9 Mass Rebuild

* Sun Jan 23 2022 tv <tv> 1.5.2-1.mga9
+ Revision: 1769563
- 1.5.2

* Tue Dec 21 2021 tv <tv> 1.5.1-1.mga9
+ Revision: 1763244
- 1.5.1

* Sat May 15 2021 tv <tv> 1.5.0-2.mga9
+ Revision: 1723398
- Re-enable testsuite

* Sat May 15 2021 tv <tv> 1.5.0-1.mga9
+ Revision: 1723392
- 1.5.0

* Thu Mar 04 2021 tv <tv> 1.4.9-1.mga9
+ Revision: 1697876
- 1.4.9

* Tue Dec 22 2020 daviddavid <daviddavid> 1.4.8-1.mga8
+ Revision: 1662830
- new version: 1.4.8

* Fri Dec 18 2020 tv <tv> 1.4.7-2.mga8
+ Revision: 1660959
- Fix alignment of scratchBuffer in HUF_compressWeights()

* Thu Dec 17 2020 tv <tv> 1.4.7-1.mga8
+ Revision: 1660447
- 1.4.7

* Wed Oct 14 2020 tv <tv> 1.4.5-4.mga8
+ Revision: 1636094
- try to re-enable the testsuite on BS

* Wed Jul 15 2020 tv <tv> 1.4.5-3.mga8
+ Revision: 1606372
- Build libzstd with multi-threading support

* Mon May 25 2020 tv <tv> 1.4.5-2.mga8
+ Revision: 1587625
- Build shared library with correct compiler flags

* Sat May 23 2020 tv <tv> 1.4.5-1.mga8
+ Revision: 1587135
- 1.4.5

* Sat May 02 2020 tv <tv> 1.4.4-3.mga8
+ Revision: 1577907
- enable to uncompress lzma files too

* Tue Feb 18 2020 umeabot <umeabot> 1.4.4-2.mga8
+ Revision: 1539494
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sun Dec 08 2019 daviddavid <daviddavid> 1.4.4-1.mga8
+ Revision: 1465151
- new version: 1.4.4

* Sun Sep 08 2019 wally <wally> 1.4.3-1.mga8
+ Revision: 1438475
- new version 1.4.3

* Sat Jul 20 2019 akien <akien> 1.4.1-1.mga8
+ Revision: 1423213
- Version 1.4.1

* Thu Apr 18 2019 akien <akien> 1.4.0-1.mga7
+ Revision: 1393195
- Version 1.4.0

* Tue Jan 01 2019 luigiwalser <luigiwalser> 1.3.8-1.mga7
+ Revision: 1347826
- 1.3.8

* Sun Oct 28 2018 ngompa <ngompa> 1.3.7-1.mga7
+ Revision: 1326305
- Update to 1.3.7

* Sun Sep 23 2018 umeabot <umeabot> 1.3.5-2.mga7
+ Revision: 1302067
- Mageia 7 Mass Rebuild

* Thu Aug 09 2018 ngompa <ngompa> 1.3.5-1.mga7
+ Revision: 1250680
- Disable automatic runs of zstd test suite for now...
- Update to 1.3.5

* Wed Apr 25 2018 ngompa <ngompa> 1.3.4-1.mga7
+ Revision: 1222353
- Update to 1.3.4
- Refresh pzstd patch from Fedora
- Use bcond for pzstd conditional

* Tue Nov 21 2017 tmb <tmb> 1.3.2-1.mga7
+ Revision: 1178202
- fix group
- adapt for Mageia
- import from fedora


* Fri Nov 10 2017 Pádraig Brady <P@draigBrady.com> - 1.3.2-1
- Latest upstream

* Mon Aug 21 2017 Pádraig Brady <P@draigBrady.com> - 1.3.1-1
- Latest upstream

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Jul 16 2017 Pádraig Brady <P@draigBrady.com> - 1.3.0-1
- Latest upstream

* Mon May 08 2017 Pádraig Brady <P@draigBrady.com> - 1.2.0-1
- Latest upstream

* Mon Mar 06 2017 Pádraig Brady <P@draigBrady.com> - 1.1.3-1
- Latest upstream

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Nov 02 2016 Pádraig Brady <pbrady@redhat.com> - 1.1.1-1
- Latest upstream

* Thu Oct 6  2016 Pádraig Brady <pbrady@fb.com> 1.1.0-2
- Add pzstd(1)

* Thu Sep 29 2016 Pádraig Brady <pbrady@fb.com> 1.1.0-1
- New upstream release
- Remove examples and static lib

* Mon Sep 12 2016 Pádraig Brady <pbrady@fb.com> 1.0.0-2
- Adjust various upstream links
- Parameterize various items in spec file

* Mon Sep 5 2016 Pádraig Brady <pbrady@fb.com> 1.0.0-1
- Initial release
